network: Display the graphical structure of a Gaussian mixture...

View source: R/network.R

networkR Documentation

Display the graphical structure of a Gaussian mixture Bayesian network

Description

This function displays the graphical structure of a Gaussian mixture Bayesian network.

Usage

network(gmbn)

Arguments

gmbn

An object of class gmbn.

Value

A visNetwork object displaying the graphical structure.

Examples

data(gmbn_body)
network(gmbn_body)

data(gmdbn_air)
network(gmdbn_air$b_2)


gmgm documentation built on Feb. 26, 2026, 1:06 a.m.